@@ -1,5 +1,7 @@
 #' Delete a pin (legacy API)
 #'
+#' `r lifecycle::badge('deprecated')`
+#'
 #' Deletes pins from a legacy board.
 #'
 #' @param name The name for the pin.
@@ -16,7 +18,9 @@
 #' board %>% pin_write(mtcars)
 #' board %>% pin_delete("mtcars")
 #' @export
+#' @keywords internal
 pin_remove <- function(name, board = NULL) {
+  lifecycle::deprecate_soft("1.4.0", "pin_remove()", "pin_delete()")
   board <- board_get(board)
   board_pin_remove(board, name)
   invisible(NULL)
