@@ -24,7 +24,7 @@
 #' board %>% pin_search("letters")
 pin_search <- function(board, search = NULL, ...) {
   check_board(board, "pin_search", "pin_find")
-  ellipsis::check_dots_used()
+  check_dots_used()
   UseMethod("pin_search")
 }
 
